@@ -7,7 +7,7 @@ use warnings;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '0.043'; # VERSION
+our $VERSION = '0.044'; # VERSION
 our $AUTHORITY = 'cpan:IMAGO'; # AUTHORITY
 
 with 'Regru::API::Role::Client';
@@ -61,7 +61,7 @@ Regru::API::Domain - REG.API v2 domain names management
 
 =head1 VERSION
 
-version 0.043
+version 0.044
 
 =head1 DESCRIPTION
 
@@ -86,7 +86,7 @@ For testing purposes. Scope: B<everyone>. Typical usage:
 
 Returns success response.
 
-More info at L<Domain management: nop|https://www.reg.com/support/help/API-version2#domain_nop>.
+More info at L<Domain management: nop|https://www.reg.com/support/help/api2#domain_nop>.
 
 =head2 get_prices
 
@@ -102,7 +102,7 @@ Get prices for domain registration/renewal in all available zones. Scope: B<ever
 Additional options might be passed to this method. Returns a list available zones and cost of domain registration/renewal
 onto the minimal required term.
 
-More info at L<Domain management: get_prices|https://www.reg.com/support/help/API-version2#domain_get_prices>.
+More info at L<Domain management: get_prices|https://www.reg.com/support/help/api2#domain_get_prices>.
 
 =head2 get_suggest
 
@@ -116,7 +116,7 @@ Gets the domain names suggestions for given word or two (as additional parameter
 
 Returns a list of alternatives and its availability in given zones. Result set is limited to I<100> items.
 
-More info at L<Domain management: get_suggest|https://www.reg.com/support/help/API-version2#domain_get_suggest>.
+More info at L<Domain management: get_suggest|https://www.reg.com/support/help/api2#domain_get_suggest>.
 
 =head2 get_premium
 
@@ -130,7 +130,7 @@ Gets a list of the premium domains available for registration. Scope: B<partners
 
 Answer contains a list each element of it contains premium domain name and its price.
 
-More info at L<Domain management: get_premium|https://www.reg.com/support/help/API-version2#domain_get_premium>.
+More info at L<Domain management: get_premium|https://www.reg.com/support/help/api2#domain_get_premium>.
 
 =head2 get_deleted
 
@@ -150,7 +150,7 @@ Answer will contains a field C<domains> with a list of domain names that satisfi
 will includes domain status, first registration date, freeing date and values of ranks (Google PR and Yandex CY).
 Maximum returned elements in list equals to 50000.
 
-More info at L<Domain management: get_deleted|https://www.reg.com/support/help/API-version2#domain_get_deleted>.
+More info at L<Domain management: get_deleted|https://www.reg.com/support/help/api2#domain_get_deleted>.
 
 =head2 check
 
@@ -171,13 +171,13 @@ Use this method to check availability of a domain name for registration. Scope:
 Response answer contains C<domains> field with list of hashes providing information about domain names and their
 availability or error code.
 
-More info at L<Domain management: check|https://www.reg.com/support/help/API-version2#domain_check>.
+More info at L<Domain management: check|https://www.reg.com/support/help/api2#domain_check>.
 
 =head2 create
 
 Apply for domain name registration. Scope: B<clients>. Typical usage:
 
-    $resp = $client->domain->check(
+    $resp = $client->domain->create(
         domain_name => 'messaline.ru',
         contacts => {
             # set of contact fields goes here (depends on zone)
@@ -192,7 +192,7 @@ Apply for domain name registration. Scope: B<clients>. Typical usage:
 
 Successful response will contains a list of domains and billing information.
 
-More info at L<Domain management: create|https://www.reg.com/support/help/API-version2#domain_create>.
+More info at L<Domain management: create|https://www.reg.com/support/help/api2#domain_create>.
 
 =head2 transfer
 
@@ -206,7 +206,7 @@ Apply for a transfer of a domain name from foreign registrar. Scope: B<clients>.
 This method has request fields similar to L<#create> method call. For the most part of the international zones such as
 C<.com>, C<.net>, C<.org> should be provided transfer key by specifying parameter authinfo.
 
-More info at L<Domain management: transfer|https://www.reg.com/support/help/API-version2#domain_transfer>.
+More info at L<Domain management: transfer|https://www.reg.com/support/help/api2#domain_transfer>.
 
 =head2 get_rereg_data
 
@@ -220,7 +220,7 @@ Gets a list of freeing domain names and their details. Scope: B<partners>. Typic
 
 Returns a domain names list for the given parameters.
 
-More info at L<Domain management: get_rereg_data|https://www.reg.com/support/help/API-version2#domain_get_rereg_data>.
+More info at L<Domain management: get_rereg_data|https://www.reg.com/support/help/api2#domain_get_rereg_data>.
 
 =head2 set_rereg_bids
 
@@ -244,7 +244,7 @@ Places a bid or bids for the freeing domain names. Scope: B<clients>. Typical us
 Answer will be contains a list of domain names and their bid status. Additionally a payment status for the placed
 bids will be returned.
 
-More info at L<Domain management: set_rereg_bids|https://www.reg.com/support/help/API-version2#domain_set_rereg_bids>.
+More info at L<Domain management: set_rereg_bids|https://www.reg.com/support/help/api2#domain_set_rereg_bids>.
 
 =head2 get_user_rereg_bids
 
@@ -254,7 +254,7 @@ Gets the bids placed on. Scope: B<clients>. Typical usage:
 
 Returns a list of a domain names for which user has placed bids on.
 
-More info at L<Domain management: get_user_rereg_bids|https://www.reg.com/support/help/API-version2#domain_get_user_rereg_bids>.
+More info at L<Domain management: get_user_rereg_bids|https://www.reg.com/support/help/api2#domain_get_user_rereg_bids>.
 
 =head2 get_docs_upload_uri
 
@@ -267,7 +267,7 @@ Scope: B<clients>. Typical usage:
 
 Answer will be contains an url that should be used to upload documents.
 
-More info at L<Domain management: get_docs_upload_uri|https://www.reg.com/support/help/API-version2#domain_get_docs_upload_uri>.
+More info at L<Domain management: get_docs_upload_uri|https://www.reg.com/support/help/api2#domain_get_docs_upload_uri>.
 
 =head2 update_contacts
 
@@ -307,7 +307,7 @@ Make changes of the domain name contact data. Scope: B<clients>. Typical usage:
 Answer will contains a domains field with list of domain names each item consist of dname, service_id and/or error_code
 parameters.
 
-More info at L<Domain management: update_contacts|https://www.reg.com/support/help/API-version2#domain_update_contacts>.
+More info at L<Domain management: update_contacts|https://www.reg.com/support/help/api2#domain_update_contacts>.
 
 =head2 update_private_person_flag
 
@@ -324,7 +324,7 @@ Scope: B<clients>. Typical usage:
 
 Answer will contains a domains field with list of domain names and operation status.
 
-More info at L<Domain management: update_private_person_flag|https://www.reg.com/support/help/API-version2#domain_update_private_person_flag>.
+More info at L<Domain management: update_private_person_flag|https://www.reg.com/support/help/api2#domain_update_private_person_flag>.
 
 =head2 register_ns
 
@@ -339,7 +339,7 @@ Domain name server registration in the NSI registry ((for internatonal domains o
 Answer will contains a C<resp> field with a detailed response from the NSI registry, typically a hash. Available
 in sussessful resposnses only.
 
-More info at L<Domain management: register_ns|https://www.reg.com/support/help/API-version2#domain_register_ns>.
+More info at L<Domain management: register_ns|https://www.reg.com/support/help/api2#domain_register_ns>.
 
 =head2 delete_ns
 
@@ -354,7 +354,7 @@ Deletion of a domain name server from the NSI registry (for international domain
 Answer will contains a C<resp> field with a detailed response from the NSI registry, typically a hash. Available
 in sussessful resposnses only.
 
-More info at L<Domain management: delete_ns|https://www.reg.com/support/help/API-version2#domain_delete_ns>.
+More info at L<Domain management: delete_ns|https://www.reg.com/support/help/api2#domain_delete_ns>.
 
 =head2 get_nss
 
@@ -374,7 +374,7 @@ Retrive a domane name servers for domain name(s). Scope: B<clients>. Typical usa
 
 Answer will contains a list of domain names and nameservers (and ip addresses if any) and/or error codes.
 
-More info at L<Domain management: get_nss|https://www.reg.com/support/help/API-version2#domain_get_nss>.
+More info at L<Domain management: get_nss|https://www.reg.com/support/help/api2#domain_get_nss>.
 
 =head2 update_nss
 
@@ -395,7 +395,7 @@ Scope: B<clients>/B<partners>. Typical usage:
 
 Answer will contains a list of domain names with the parameters dname, service_id and/or a service identification error_code.
 
-More info at L<Domain management: update_nss|https://www.reg.com/support/help/API-version2#domain_update_nss>.
+More info at L<Domain management: update_nss|https://www.reg.com/support/help/api2#domain_update_nss>.
 
 =head2 delegate
 
@@ -410,7 +410,7 @@ Turn on a domain name delegation flag. Scope: B<partners>. Typical usage:
 
 Answer will contains a list of domain names with the parameters dname, service_id and/or a service identification error_code.
 
-More info at L<Domain management: delegate|https://www.reg.com/support/help/API-version2#domain_delegate>.
+More info at L<Domain management: delegate|https://www.reg.com/support/help/api2#domain_delegate>.
 
 =head2 undelegate
 
@@ -425,7 +425,7 @@ Turn off a domain name delegation flag. Scope: B<partners>. Typical usage:
 
 Answer will contains a list of domain names with the parameters dname, service_id and/or a service identification error_code.
 
-More info at L<Domain management: undelegate|https://www.reg.com/support/help/API-version2#domain_undelegate>.
+More info at L<Domain management: undelegate|https://www.reg.com/support/help/api2#domain_undelegate>.
 
 =head2 transfer_to_another_account
 
@@ -440,7 +440,7 @@ Answer will contains a list of domain names transferred to another account. In c
 C<result> there will be the B<request_is_sent> value for each domain name in the C<result> field, otherwise an
 error code will be returned.
 
-More info at L<Domain management: transfer_to_another_account|https://www.reg.com/support/help/API-version2#domain_transfer_to_another_account>.
+More info at L<Domain management: transfer_to_another_account|https://www.reg.com/support/help/api2#domain_transfer_to_another_account>.
 
 =head2 look_at_entering_list
 
@@ -451,7 +451,7 @@ Show the list of domain names transferred to current account. Scope: B<partners>
 Answer will contains a list of messages about domain names transfer. Each message contains an ID and the name of
 the transferred domain. Upon each transfer domain names are assigned to new user ID.
 
-More info at L<Domain management: look_at_entering_list|https://www.reg.com/support/help/API-version2#domain_look_at_entering_list>.
+More info at L<Domain management: look_at_entering_list|https://www.reg.com/support/help/api2#domain_look_at_entering_list>.
 
 =head2 accept_or_refuse_entering_list
 
@@ -465,7 +465,7 @@ Accept or decline domain names transferred to current account. Scope: B<partners
 
 Answer will contains a list of domain names with result for each domain name.
 
-More info at L<Domain management: accept_or_refuse_entering_list|https://www.reg.com/support/help/API-version2#domain_accept_or_refuse_entering_list>.
+More info at L<Domain management: accept_or_refuse_entering_list|https://www.reg.com/support/help/api2#domain_accept_or_refuse_entering_list>.
 
 =head2 cancel_transfer
 
@@ -480,7 +480,7 @@ Shut down transfers of the domain names. Scope: B<partners>. Typical usage:
 
 Answer will contains a list of domain names with result for each domain name.
 
-More info at L<Domain management: cancel_transfer|https://www.reg.com/support/help/API-version2#domain_cancel_transfer>.
+More info at L<Domain management: cancel_transfer|https://www.reg.com/support/help/api2#domain_cancel_transfer>.
 
 =head2 request_to_transfer
 
@@ -492,7 +492,7 @@ Send request to transfer a domain name to foreign registrar. Scope: B<partners>.
 
 Answer will contains a list of domain names with result for each domain name.
 
-More info at L<Domain management: request_to_transfer|https://www.reg.com/support/help/API-version2#domain_request_to_transfer>.
+More info at L<Domain management: request_to_transfer|https://www.reg.com/support/help/api2#domain_request_to_transfer>.
 
 =head1 SEE ALSO
 
@@ -500,9 +500,9 @@ L<Regru::API>
 
 L<Regru::API::Role::Client>
 
-L<REG.API Domain management|https://www.reg.com/support/help/API-version2#domain_fn>
+L<REG.API Domain management|https://www.reg.com/support/help/api2#domain_functions>
 
-L<REG.API Common error codes|https://www.reg.com/support/help/API-version2#std_error_codes>.
+L<REG.API Common error codes|https://www.reg.com/support/help/api2#common_errors>
 
 =head1 BUGS
 
