@@ -7,7 +7,7 @@ use warnings;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '0.043'; # VERSION
+our $VERSION = '0.044'; # VERSION
 our $AUTHORITY = 'cpan:IMAGO'; # AUTHORITY
 
 with 'Regru::API::Role::Client';
@@ -41,7 +41,7 @@ Regru::API::User - REG.API v2 user account management
 
 =head1 VERSION
 
-version 0.043
+version 0.044
 
 =head1 DESCRIPTION
 
@@ -63,7 +63,7 @@ For testing purposes. Scope: B<everyone>. Typical usage:
 
 Returns success response.
 
-More info at L<Account management: nop|https://www.reg.com/support/help/API-version2#user_nop>.
+More info at L<Account management: nop|https://www.reg.com/support/help/api2#user_nop>.
 
 =head2 create
 
@@ -85,7 +85,7 @@ Creates a new user account. Scope: B<partners>. Typical usage:
 Answer will contains an C<user_id> field for newly created user account or error otherwise.
 
 There are a lot of optional fields related to user account so check the documentation if you wish to use them.
-More info at L<Account management: create|https://www.reg.com/support/help/API-version2#user_create>.
+More info at L<Account management: create|https://www.reg.com/support/help/api2#user_create>.
 
 =head2 get_statistics
 
@@ -99,7 +99,7 @@ Fetch usage statistic for current account. Scope: B<clients>. Typical usage:
 Parameters C<date_from> and C<date_till> are optional. Answer will contains a set of metrics such as number of active
 domain names, number of domain names which are subject to renewal, number of folders, etc.
 
-More info at L<Account management: get_statistics|https://www.reg.com/support/help/API-version2#user_get_statistics>.
+More info at L<Account management: get_statistics|https://www.reg.com/support/help/api2#user_get_statistics>.
 
 =head2 get_balance
 
@@ -112,7 +112,7 @@ Shows a current user account balance. Scope: B<clients>. Typical usage:
 Answer will contains a set of fields like amount of available funds, amount of a blocked funds. For resellers (partners)
 will be shown amount of available credit additionally.
 
-More info at L<Account management: get_balance|https://www.reg.com/support/help/API-version2#user_get_balance>.
+More info at L<Account management: get_balance|https://www.reg.com/support/help/api2#user_get_balance>.
 
 =head2 refill_balance
 
@@ -127,7 +127,7 @@ Tops up an user account balance with Webmoney or Yandex.Money. Scope: B<clients>
 
 Answer will contains an invoice ID and other payment details or error otherwise.
 
-More info at L<Account management: refill_balance|https://www.reg.com/support/help/API-version2#user_refill_balance>.
+More info at L<Account management: refill_balance|https://www.reg.com/support/help/api2#user_refill_balance>.
 
 =head1 SEE ALSO
 
@@ -135,9 +135,9 @@ L<Regru::API>
 
 L<Regru::API::Role::Client>
 
-L<REG.API Account management|https://www.reg.com/support/help/API-version2#user_fn>
+L<REG.API Account management|https://www.reg.com/support/help/api2#user_functions>
 
-L<REG.API Common error codes|https://www.reg.com/support/help/API-version2#std_error_codes>.
+L<REG.API Common error codes|https://www.reg.com/support/help/api2#common_errors>
 
 =head1 BUGS
 
